==> xlniuxdata-jinzuan-1.0.4-20141021.062936-1-sources.jar: com/xunlei/niux/data/jinzuan/vo/PayOrder.java <==
package com.xunlei.niux.data.jinzuan.vo;



import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;


/**
 * 支付订单
 * @author lisu
 * 2014-03-03
 */
@Table(tableName="jinzuan_payorder",pkFieldName="seqId",pkFieldAssign=false)
public class PayOrder {
	
	private Long seqId;
    private Long userId;
    private String actNo;
    private String bizNo;
    private String orderId;
    private String chargeType;
	private String bankNo;
	private Integer orderType;
	private Integer timeType;
    private Long numValue;
    private Double orderMoney;
	private Double payMoney;
    private String orderTime;
    private Integer orderStatus;
    private String finishTime;
    private String userName;
    private String ext1;
    private String ip;
    private String payBizNo;
    private Boolean noticeActivity; 
    private String acode;
    
    
	@Column(columnName="orderTime",isWhereColumn=true,operator=Operator.GE)
	private String fromdaytime;
	@Column(columnName="orderTime",isWhereColumn=true,operator=Operator.LT)
	private String todaytime;
	
	@Column(columnName="finishTime",isWhereColumn=true,operator=Operator.GE)
	private String fromfinishTime;
	@Column(columnName="finishTime",isWhereColumn=true,operator=Operator.LT)
	private String tofinishTime;
	private String advNo;
	
	
    
	public String getAdvNo() {
		return advNo;
	}
	public void setAdvNo(String advNo) {
		this.advNo = advNo;
	}
	public String getAcode() {
		return acode;
	}
	public void setAcode(String acode) {
		this.acode = acode;
	}
	public Boolean getNoticeActivity() {
		return noticeActivity;
	}
	public void setNoticeActivity(Boolean noticeActivity) {
		this.noticeActivity = noticeActivity;
	}
	public String getFromfinishTime() {
		return fromfinishTime;
	}
	public void setFromfinishTime(String fromfinishTime) {
		this.fromfinishTime = fromfinishTime;
	}
	public String getTofinishTime() {
		return tofinishTime;
	}
	public void setTofinishTime(String tofinishTime) {
		this.tofinishTime = tofinishTime;
	}
	public String getFromdaytime() {
		return fromdaytime;
	}
	public void setFromdaytime(String fromdaytime) {
		this.fromdaytime = fromdaytime;
	}
	public String getTodaytime() {
		return todaytime;
	}
	public void setTodaytime(String todaytime) {
		this.todaytime = todaytime;
	}
    
    public Double getOrderMoney() {
		return orderMoney;
	}
	public void setOrderMoney(Double orderMoney) {
		this.orderMoney = orderMoney;
	}
    public Integer getOrderType() {
		return orderType;
	}
	public void setOrderType(Integer orderType) {
		this.orderType = orderType;
	}
	public Integer getTimeType() {
		return timeType;
	}
	public void setTimeType(Integer timeType) {
		this.timeType = timeType;
	}
	public Long getNumValue() {
		return numValue;
	}
	public void setNumValue(Long numValue) {
		this.numValue = numValue;
	}
	public String getIp() {
		return ip;
	}
	public void setIp(String ip) {
		this.ip = ip;
	}
	public String getPayBizNo() {
		return payBizNo;
	}
	public void setPayBizNo(String payBizNo) {
		this.payBizNo = payBizNo;
	}
    public String getExt1() {
		return ext1;
	}
	public void setExt1(String ext1) {
		this.ext1 = ext1;
	}
	public String getUserName() {
		return userName;
	}
	public void setUserName(String userName) {
		this.userName = userName;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public Long getUserId() {
		return userId;
	}
	public void setUserId(Long userId) {
		this.userId = userId;
	}
	public String getActNo() {
		return actNo;
	}
	public void setActNo(String actNo) {
		this.actNo = actNo;
	}
	public String getBizNo() {
		return bizNo;
	}
	public void setBizNo(String bizNo) {
		this.bizNo = bizNo;
	}
	public String getOrderId() {
		return orderId;
	}
	public void setOrderId(String orderId) {
		this.orderId = orderId;
	}
    public String getChargeType() {
		return chargeType;
	}
	public void setChargeType(String chargeType) {
		this.chargeType = chargeType;
	}
	public String getBankNo() {
		return bankNo;
	}
	public void setBankNo(String bankNo) {
		this.bankNo = bankNo;
	}
   
	public Double getPayMoney() {
		return payMoney;
	}
	public void setPayMoney(Double payMoney) {
		this.payMoney = payMoney;
	}
	public String getOrderTime() {
		return orderTime;
	}
	public void setOrderTime(String orderTime) {
		this.orderTime = orderTime;
	}
	public Integer getOrderStatus() {
		return orderStatus;
	}
	public void setOrderStatus(Integer orderStatus) {
		this.orderStatus = orderStatus;
	}
	public String getFinishTime() {
		return finishTime;
	}
	public void setFinishTime(String finishTime) {
		this.finishTime = finishTime;
	}
    
}

==> xlniuxdata-jinzuan-1.0.4-20150828.095541-9-sources.jar: com/xunlei/niux/data/jinzuan/vo/PayOrder.java <==
package com.xunlei.niux.data.jinzuan.vo;



import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;


/**
 * 支付订单
 * @author lisu
 * 2014-03-03
 */
@Table(tableName="jinzuan_payorder",pkFieldName="seqId",pkFieldAssign=false)
public class PayOrder {
	
	private Long seqId;
    private Long userId;
    private String actNo;
    private String bizNo;
    private String orderId;
    private String chargeType;
	private String bankNo;
	private Integer orderType;
	private Integer timeType;
    private Long numValue;
    private Double orderMoney;
	private Double payMoney;
    private String orderTime;
    private Integer orderStatus;
    private String finishTime;
    private String userName;
    private String ext1;
    private String ip;
    private String payBizNo;
    private Boolean noticeActivity; 
    private String acode;
    
    
	@Column(columnName="orderTime",isWhereColumn=true,operator=Operator.GE)
	private String fromdaytime;
	@Column(columnName="orderTime",isWhereColumn=true,operator=Operator.LT)
	private String todaytime;
	
	@Column(columnName="finishTime",isWhereColumn=true,operator=Operator.GE)
	private String fromfinishTime;
	@Column(columnName="finishTime",isWhereColumn=true,operator=Operator.LT)
	private String tofinishTime;
	private String advNo;
	private Integer memberStatus;
	
	
	
    
	public Integer getMemberStatus() {
		return memberStatus;
	}
	public void setMemberStatus(Integer memberStatus) {
		this.memberStatus = memberStatus;
	}
	public String getAdvNo() {
		return advNo;
	}
	public void setAdvNo(String advNo) {
		this.advNo = advNo;
	}
	public String getAcode() {
		return acode;
	}
	public void setAcode(String acode) {
		this.acode = acode;
	}
	public Boolean getNoticeActivity() {
		return noticeActivity;
	}
	public void setNoticeActivity(Boolean noticeActivity) {
		this.noticeActivity = noticeActivity;
	}
	public String getFromfinishTime() {
		return fromfinishTime;
	}
	public void setFromfinishTime(String fromfinishTime) {
		this.fromfinishTime = fromfinishTime;
	}
	public String getTofinishTime() {
		return tofinishTime;
	}
	public void setTofinishTime(String tofinishTime) {
		this.tofinishTime = tofinishTime;
	}
	public String getFromdaytime() {
		return fromdaytime;
	}
	public void setFromdaytime(String fromdaytime) {
		this.fromdaytime = fromdaytime;
	}
	public String getTodaytime() {
		return todaytime;
	}
	public void setTodaytime(String todaytime) {
		this.todaytime = todaytime;
	}
    
    public Double getOrderMoney() {
		return orderMoney;
	}
	public void setOrderMoney(Double orderMoney) {
		this.orderMoney = orderMoney;
	}
    public Integer getOrderType() {
		return orderType;
	}
	public void setOrderType(Integer orderType) {
		this.orderType = orderType;
	}
	public Integer getTimeType() {
		return timeType;
	}
	public void setTimeType(Integer timeType) {
		this.timeType = timeType;
	}
	public Long getNumValue() {
		return numValue;
	}
	public void setNumValue(Long numValue) {
		this.numValue = numValue;
	}
	public String getIp() {
		return ip;
	}
	public void setIp(String ip) {
		this.ip = ip;
	}
	public String getPayBizNo() {
		return payBizNo;
	}
	public void setPayBizNo(String payBizNo) {
		this.payBizNo = payBizNo;
	}
    public String getExt1() {
		return ext1;
	}
	public void setExt1(String ext1) {
		this.ext1 = ext1;
	}
	public String getUserName() {
		return userName;
	}
	public void setUserName(String userName) {
		this.userName = userName;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public Long getUserId() {
		return userId;
	}
	public void setUserId(Long userId) {
		this.userId = userId;
	}
	public String getActNo() {
		return actNo;
	}
	public void setActNo(String actNo) {
		this.actNo = actNo;
	}
	public String getBizNo() {
		return bizNo;
	}
	public void setBizNo(String bizNo) {
		this.bizNo = bizNo;
	}
	public String getOrderId() {
		return orderId;
	}
	public void setOrderId(String orderId) {
		this.orderId = orderId;
	}
    public String getChargeType() {
		return chargeType;
	}
	public void setChargeType(String chargeType) {
		this.chargeType = chargeType;
	}
	public String getBankNo() {
		return bankNo;
	}
	public void setBankNo(String bankNo) {
		this.bankNo = bankNo;
	}
   
	public Double getPayMoney() {
		return payMoney;
	}
	public void setPayMoney(Double payMoney) {
		this.payMoney = payMoney;
	}
	public String getOrderTime() {
		return orderTime;
	}
	public void setOrderTime(String orderTime) {
		this.orderTime = orderTime;
	}
	public Integer getOrderStatus() {
		return orderStatus;
	}
	public void setOrderStatus(Integer orderStatus) {
		this.orderStatus = orderStatus;
	}
	public String getFinishTime() {
		return finishTime;
	}
	public void setFinishTime(String finishTime) {
		this.finishTime = finishTime;
	}
    
}
